This is an automated email from the ASF dual-hosted git repository.

tustvold pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/arrow-rs.git


The following commit(s) were added to refs/heads/master by this push:
     new 756505495 Fix typos (#3985)
756505495 is described below

commit 756505495103ef67ec2c44e78ea117c4936ce959
Author: Yang Xiufeng <[email protected]>
AuthorDate: Fri Mar 31 18:59:44 2023 +0800

    Fix typos (#3985)
    
    * fix typos in comments
    
    * fix typos in changelog.
    
    * fix typos in readme.
    
    * fix typos in string literals.
    
    * fix typos in unit tests func names.
    
    * fix typos in codes.
---
 CHANGELOG-old.md                              | 36 ++++++++---------
 arrow-array/src/array/list_array.rs           |  2 +-
 arrow-array/src/array/map_array.rs            |  2 +-
 arrow-array/src/array/mod.rs                  |  6 +--
 arrow-array/src/array/run_array.rs            |  2 +-
 arrow-array/src/array/string_array.rs         |  2 +-
 arrow-array/src/array/union_array.rs          |  2 +-
 arrow-array/src/cast.rs                       |  2 +-
 arrow-array/src/types.rs                      |  4 +-
 arrow-csv/src/reader/mod.rs                   | 10 ++---
 arrow-data/src/data/mod.rs                    |  2 +-
 arrow-data/src/transform/mod.rs               |  8 ++--
 arrow-flight/src/client.rs                    |  2 +-
 arrow-flight/src/error.rs                     |  2 +-
 arrow-flight/tests/encode_decode.rs           | 56 +++++++++++++--------------
 arrow-integration-testing/tests/ipc_reader.rs |  2 +-
 arrow-ipc/src/compression.rs                  |  2 +-
 arrow-ipc/src/convert.rs                      |  2 +-
 arrow-json/src/reader.rs                      |  4 +-
 arrow-json/src/writer.rs                      |  6 +--
 arrow-ord/src/sort.rs                         |  4 +-
 arrow-select/src/take.rs                      |  2 +-
 arrow/examples/README.md                      |  2 +-
 arrow/src/util/bench_util.rs                  |  2 +-
 arrow/src/util/data_gen.rs                    |  2 +-
 dev/release/README.md                         |  6 +--
 object_store/CHANGELOG-old.md                 |  2 +-
 object_store/src/azure/client.rs              |  2 +-
 parquet/src/arrow/arrow_reader/mod.rs         |  2 +-
 parquet/src/arrow/arrow_reader/selection.rs   |  2 +-
 parquet/src/basic.rs                          |  2 +-
 parquet/src/compression.rs                    |  2 +-
 parquet/src/data_type.rs                      |  4 +-
 parquet/src/file/serialized_reader.rs         |  2 +-
 parquet/src/record/api.rs                     |  2 +-
 parquet/src/record/reader.rs                  |  2 +-
 parquet/src/record/triplet.rs                 |  2 +-
 37 files changed, 98 insertions(+), 98 deletions(-)

diff --git a/CHANGELOG-old.md b/CHANGELOG-old.md
index 8ddd7c6b6..ebdab71b2 100644
--- a/CHANGELOG-old.md
+++ b/CHANGELOG-old.md
@@ -159,7 +159,7 @@
 - Support UTF8 cast to Timestamp with timezone 
[\#3664](https://github.com/apache/arrow-rs/issues/3664)
 - Add modulus\_dyn and modulus\_scalar\_dyn 
[\#3648](https://github.com/apache/arrow-rs/issues/3648) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - A trait for append\_value and append\_null on ArrayBuilders 
[\#3644](https://github.com/apache/arrow-rs/issues/3644)
-- Improve error messge "batches\[0\] schema is different with argument schema" 
[\#3628](https://github.com/apache/arrow-rs/issues/3628) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
+- Improve error message "batches\[0\] schema is different with argument 
schema" [\#3628](https://github.com/apache/arrow-rs/issues/3628) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Specified version of helper function to cast binary to string 
[\#3623](https://github.com/apache/arrow-rs/issues/3623) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Casting generic binary to generic string 
[\#3606](https://github.com/apache/arrow-rs/issues/3606) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Use `array_value_to_string` in `arrow-csv`  
[\#3483](https://github.com/apache/arrow-rs/issues/3483) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
@@ -201,7 +201,7 @@
 - Include line and field number in CSV UTF-8 error \(\#3656\) 
[\#3657](https://github.com/apache/arrow-rs/pull/3657) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([tustvold](https://github.com/tustvold))
 - Handle non-contiguous type\_ids in UnionArray \(\#3653\) 
[\#3654](https://github.com/apache/arrow-rs/pull/3654) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([tustvold](https://github.com/tustvold))
 - Add modulus\_dyn and modulus\_scalar\_dyn 
[\#3649](https://github.com/apache/arrow-rs/pull/3649) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([viirya](https://github.com/viirya))
-- Improve error messge with detailed schema 
[\#3637](https://github.com/apache/arrow-rs/pull/3637) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([Veeupup](https://github.com/Veeupup))
+- Improve error message with detailed schema 
[\#3637](https://github.com/apache/arrow-rs/pull/3637) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([Veeupup](https://github.com/Veeupup))
 - Add limit to ArrowReaderBuilder to push limit down to parquet reader 
[\#3633](https://github.com/apache/arrow-rs/pull/3633) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)] 
([thinkharderdev](https://github.com/thinkharderdev))
 - chore: delete wrong comment and refactor set\_metadata in `Field` 
[\#3630](https://github.com/apache/arrow-rs/pull/3630) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([chunshao90](https://github.com/chunshao90))
 - Fix typo in comment [\#3627](https://github.com/apache/arrow-rs/pull/3627) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)] 
([kjschiroo](https://github.com/kjschiroo))
@@ -245,7 +245,7 @@
 
 - Nullif of NULL Predicate is not NULL 
[\#3589](https://github.com/apache/arrow-rs/issues/3589)
 - BooleanBufferBuilder Fails to Clear Set Bits On Truncate 
[\#3587](https://github.com/apache/arrow-rs/issues/3587) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
-- `nullif` incorrectly calculates `null_count`, sometimes panics with 
substraction overflow error 
[\#3579](https://github.com/apache/arrow-rs/issues/3579) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
+- `nullif` incorrectly calculates `null_count`, sometimes panics with 
subtraction overflow error 
[\#3579](https://github.com/apache/arrow-rs/issues/3579) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Meet warning when use pyarrow 
[\#3543](https://github.com/apache/arrow-rs/issues/3543) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Incorrect row group total\_byte\_size written to parquet file 
[\#3530](https://github.com/apache/arrow-rs/issues/3530) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
 - Overflow when casting timestamps prior to the epoch 
[\#3512](https://github.com/apache/arrow-rs/issues/3512) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
@@ -538,7 +538,7 @@
 - Update prost-build requirement from =0.11.2 to =0.11.3 
[\#3225](https://github.com/apache/arrow-rs/pull/3225) 
[[arrow-flight](https://github.com/apache/arrow-rs/labels/arrow-flight)] 
([dependabot[bot]](https://github.com/apps/dependabot))
 - Get the round result for decimal to a decimal with smaller scale  
[\#3224](https://github.com/apache/arrow-rs/pull/3224) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([liukun4515](https://github.com/liukun4515))
 - Move tests which require chrono-tz feature from `arrow-cast` to `arrow` 
[\#3222](https://github.com/apache/arrow-rs/pull/3222) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([viirya](https://github.com/viirya))
-- add test cases for extracing week with/without timezone 
[\#3218](https://github.com/apache/arrow-rs/pull/3218) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([waitingkuo](https://github.com/waitingkuo))
+- add test cases for extracting week with/without timezone 
[\#3218](https://github.com/apache/arrow-rs/pull/3218) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([waitingkuo](https://github.com/waitingkuo))
 - Use RegexSet for matching DataType 
[\#3217](https://github.com/apache/arrow-rs/pull/3217) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([askoa](https://github.com/askoa))
 - Update tonic-build to 0.8.3 
[\#3214](https://github.com/apache/arrow-rs/pull/3214) 
[[arrow-flight](https://github.com/apache/arrow-rs/labels/arrow-flight)] 
([tustvold](https://github.com/tustvold))
 - Support StructArray in Row Format \(\#3159\) 
[\#3212](https://github.com/apache/arrow-rs/pull/3212) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([tustvold](https://github.com/tustvold))
@@ -600,7 +600,7 @@
 
 **Fixed bugs:**
 
-- arithmatic overflow leads to segfault in `concat_batches` 
[\#3123](https://github.com/apache/arrow-rs/issues/3123) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
+- arithmetic overflow leads to segfault in `concat_batches` 
[\#3123](https://github.com/apache/arrow-rs/issues/3123) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Clippy failing on master : error: use of deprecated associated function 
chrono::NaiveDate::from\_ymd: use from\_ymd\_opt\(\) instead 
[\#3097](https://github.com/apache/arrow-rs/issues/3097) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)] 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Pretty print for interval types has wrong formatting 
[\#3092](https://github.com/apache/arrow-rs/issues/3092) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Field is not serializable with binary formats 
[\#3082](https://github.com/apache/arrow-rs/issues/3082) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
@@ -1142,7 +1142,7 @@
 - Use same codebase for boolean kernels 
[\#2507](https://github.com/apache/arrow-rs/issues/2507) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Use u8 for Decimal Precision and Scale 
[\#2496](https://github.com/apache/arrow-rs/issues/2496) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Integrate skip row without pageIndex in SerializedPageReader in Fuzz Test 
[\#2475](https://github.com/apache/arrow-rs/issues/2475) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
-- Avoid unecessary copies in Arrow IPC reader 
[\#2437](https://github.com/apache/arrow-rs/issues/2437) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
+- Avoid unnecessary copies in Arrow IPC reader 
[\#2437](https://github.com/apache/arrow-rs/issues/2437) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Add GenericColumnReader::skip\_records Missing OffsetIndex Fallback 
[\#2433](https://github.com/apache/arrow-rs/issues/2433) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
 - Support Reading PageIndex with ParquetRecordBatchStream 
[\#2430](https://github.com/apache/arrow-rs/issues/2430) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
 - Specialize FixedLenByteArrayReader for Parquet 
[\#2318](https://github.com/apache/arrow-rs/issues/2318) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
@@ -1151,11 +1151,11 @@
 **Fixed bugs:**
 
 - Casting timestamp array to string should not ignore timezone 
[\#2607](https://github.com/apache/arrow-rs/issues/2607) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
-- Ilike\_ut8\_scalar kernals have incorrect logic 
[\#2544](https://github.com/apache/arrow-rs/issues/2544) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
+- Ilike\_ut8\_scalar kernels have incorrect logic 
[\#2544](https://github.com/apache/arrow-rs/issues/2544) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Always validate the array data when creating array in IPC reader 
[\#2541](https://github.com/apache/arrow-rs/issues/2541) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Int96Converter Truncates Timestamps 
[\#2480](https://github.com/apache/arrow-rs/issues/2480) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
 - Error Reading Page Index When Not Available  
[\#2434](https://github.com/apache/arrow-rs/issues/2434) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
-- `ParquetFileArrowReader::get_record_reader[_by_colum]` `batch_size` 
overallocates [\#2321](https://github.com/apache/arrow-rs/issues/2321) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
+- `ParquetFileArrowReader::get_record_reader[_by_column]` `batch_size` 
overallocates [\#2321](https://github.com/apache/arrow-rs/issues/2321) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
 
 **Documentation updates:**
 
@@ -1197,7 +1197,7 @@
 - Compare dictionary array with string array 
[\#2549](https://github.com/apache/arrow-rs/pull/2549) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([viirya](https://github.com/viirya))
 - Always validate the array data \(except the `Decimal`\) when creating array 
in IPC reader [\#2547](https://github.com/apache/arrow-rs/pull/2547) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([HaoYang670](https://github.com/HaoYang670))
 - MINOR: Fix test\_row\_type\_validation test 
[\#2546](https://github.com/apache/arrow-rs/pull/2546) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([viirya](https://github.com/viirya))
-- Fix ilike\_utf8\_scalar kernals 
[\#2545](https://github.com/apache/arrow-rs/pull/2545) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([psvri](https://github.com/psvri))
+- Fix ilike\_utf8\_scalar kernels 
[\#2545](https://github.com/apache/arrow-rs/pull/2545) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([psvri](https://github.com/psvri))
 - fix typo [\#2540](https://github.com/apache/arrow-rs/pull/2540) 
([00Masato](https://github.com/00Masato))
 - Compare dictionary array and primitive array in lt\_dyn, lt\_eq\_dyn, 
gt\_dyn, gt\_eq\_dyn kernels 
[\#2539](https://github.com/apache/arrow-rs/pull/2539) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([viirya](https://github.com/viirya))
 - \[MINOR\]Avoid large over allocate buffer in async reader 
[\#2537](https://github.com/apache/arrow-rs/pull/2537) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)] 
([Ted-Jiang](https://github.com/Ted-Jiang))
@@ -1627,7 +1627,7 @@
 - Incorrect `null_count` of DictionaryArray 
[\#1962](https://github.com/apache/arrow-rs/issues/1962) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Support multi diskRanges for ChunkReader 
[\#1955](https://github.com/apache/arrow-rs/issues/1955) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
 - Persisting Arrow timestamps with Parquet produces missing `TIMESTAMP` in 
schema [\#1920](https://github.com/apache/arrow-rs/issues/1920) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
-- Sperate get\_next\_page\_header from get\_next\_page in PageReader 
[\#1834](https://github.com/apache/arrow-rs/issues/1834) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
+- Separate get\_next\_page\_header from get\_next\_page in PageReader 
[\#1834](https://github.com/apache/arrow-rs/issues/1834) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
 
 **Merged pull requests:**
 
@@ -1684,7 +1684,7 @@
 - `PrimitiveArray::from_iter` should omit validity buffer if all values are 
valid [\#1856](https://github.com/apache/arrow-rs/issues/1856) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Add `from(v: Vec<Option<&[u8]>>)` and `from(v: Vec<&[u8]>)` for 
`FixedSizedBInaryArray` 
[\#1852](https://github.com/apache/arrow-rs/issues/1852) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Add `Vec`-inspired APIs to `BufferBuilder` 
[\#1850](https://github.com/apache/arrow-rs/issues/1850) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
-- PyArrow intergation test for C Stream Interface 
[\#1847](https://github.com/apache/arrow-rs/issues/1847) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
+- PyArrow integration test for C Stream Interface 
[\#1847](https://github.com/apache/arrow-rs/issues/1847) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Add `nilike` support in `comparison` 
[\#1845](https://github.com/apache/arrow-rs/issues/1845) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Split up `arrow::array::builder` module 
[\#1843](https://github.com/apache/arrow-rs/issues/1843) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Add `quarter` support in `temporal` kernels 
[\#1835](https://github.com/apache/arrow-rs/issues/1835) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
@@ -2081,7 +2081,7 @@
 
 **Fixed bugs:**
 
-- Error Infering Schema for LogicalType::UNKNOWN 
[\#1557](https://github.com/apache/arrow-rs/issues/1557) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
+- Error Inferring Schema for LogicalType::UNKNOWN 
[\#1557](https://github.com/apache/arrow-rs/issues/1557) 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)]
 - Read dictionary from nested struct in ipc stream reader panics 
[\#1549](https://github.com/apache/arrow-rs/issues/1549) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - `filter` produces invalid sparse `UnionArray`s 
[\#1547](https://github.com/apache/arrow-rs/issues/1547) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Documentation for `GenericListBuilder` is not exposed.  
[\#1518](https://github.com/apache/arrow-rs/issues/1518) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
@@ -2607,7 +2607,7 @@
 * 
[094037d418381584178db1d886cad3b5024b414a](https://github.com/apache/arrow-rs/commit/094037d418381584178db1d886cad3b5024b414a)
 Update comfy-table to 5.0 
([#957](https://github.com/apache/arrow-rs/pull/957)) 
([#964](https://github.com/apache/arrow-rs/pull/964))
 * 
[9f635021eee6786c5377c891218c5f88ebce07c3](https://github.com/apache/arrow-rs/commit/9f635021eee6786c5377c891218c5f88ebce07c3)
 Fix csv writing of timestamps to show timezone. 
([#849](https://github.com/apache/arrow-rs/pull/849)) 
([#963](https://github.com/apache/arrow-rs/pull/963))
 * 
[f7deba4c3a050a52608462ee8a827bb8f6364140](https://github.com/apache/arrow-rs/commit/f7deba4c3a050a52608462ee8a827bb8f6364140)
 Adding ability to parse float from number with leading decimal 
([#831](https://github.com/apache/arrow-rs/pull/831)) 
([#962](https://github.com/apache/arrow-rs/pull/962))
-* 
[59f96e842d05b63882f7ba285c66a9739761cf84](https://github.com/apache/arrow-rs/commit/59f96e842d05b63882f7ba285c66a9739761cf84)
 add ilike comparitor ([#874](https://github.com/apache/arrow-rs/pull/874)) 
([#961](https://github.com/apache/arrow-rs/pull/961))
+* 
[59f96e842d05b63882f7ba285c66a9739761cf84](https://github.com/apache/arrow-rs/commit/59f96e842d05b63882f7ba285c66a9739761cf84)
 add ilike comparator ([#874](https://github.com/apache/arrow-rs/pull/874)) 
([#961](https://github.com/apache/arrow-rs/pull/961))
 * 
[54023c8a5543c9f9fa4955afa01189029f3e96f5](https://github.com/apache/arrow-rs/commit/54023c8a5543c9f9fa4955afa01189029f3e96f5)
 Remove unpassable cargo publish check from verify-release-candidate.sh 
([#882](https://github.com/apache/arrow-rs/pull/882)) 
([#949](https://github.com/apache/arrow-rs/pull/949))
 
 
@@ -2704,7 +2704,7 @@
 **Fixed bugs:**
 
 - Converting from string to timestamp uses microseconds instead of 
milliseconds [\#780](https://github.com/apache/arrow-rs/issues/780)
-- Document has no link to `RowColumIter` 
[\#762](https://github.com/apache/arrow-rs/issues/762)
+- Document has no link to `RowColumnIter` 
[\#762](https://github.com/apache/arrow-rs/issues/762)
 - length on slices with null doesn't work 
[\#744](https://github.com/apache/arrow-rs/issues/744)
 
 ## [5.4.0](https://github.com/apache/arrow-rs/tree/5.4.0) (2021-09-10)
@@ -2762,7 +2762,7 @@
 - Remove undefined behavior in `value` method of boolean and primitive arrays 
[\#645](https://github.com/apache/arrow-rs/issues/645)
 - Avoid materialization of indices in filter\_record\_batch for single arrays 
[\#636](https://github.com/apache/arrow-rs/issues/636)
 - Add a note about arrow crate security / safety 
[\#627](https://github.com/apache/arrow-rs/issues/627)
-- Allow the creation of String arrays from an interator of &Option\<&str\> 
[\#598](https://github.com/apache/arrow-rs/issues/598)
+- Allow the creation of String arrays from an iterator of &Option\<&str\> 
[\#598](https://github.com/apache/arrow-rs/issues/598)
 - Support arrow map datatype 
[\#395](https://github.com/apache/arrow-rs/issues/395)
 
 **Fixed bugs:**
@@ -2891,7 +2891,7 @@
 - Add C data interface for decimal128 and timestamp 
[\#453](https://github.com/apache/arrow-rs/pull/453) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([alippai](https://github.com/alippai))
 - Implement the Iterator trait for the json Reader. 
[\#451](https://github.com/apache/arrow-rs/pull/451) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([LaurentMazare](https://github.com/LaurentMazare))
 - Update release docs + release email template 
[\#450](https://github.com/apache/arrow-rs/pull/450) 
([alamb](https://github.com/alamb))
-- remove clippy unnecessary wraps suppresions in cast kernel 
[\#449](https://github.com/apache/arrow-rs/pull/449) 
([Jimexist](https://github.com/Jimexist))
+- remove clippy unnecessary wraps suppression in cast kernel 
[\#449](https://github.com/apache/arrow-rs/pull/449) 
([Jimexist](https://github.com/Jimexist))
 - Use partition for bool sort 
[\#448](https://github.com/apache/arrow-rs/pull/448) 
([Jimexist](https://github.com/Jimexist))
 - remove unnecessary wraps in sort 
[\#445](https://github.com/apache/arrow-rs/pull/445) 
([Jimexist](https://github.com/Jimexist))
 - Python FFI bridge for Schema, Field and DataType  
[\#439](https://github.com/apache/arrow-rs/pull/439) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([kszucs](https://github.com/kszucs))
@@ -2964,7 +2964,7 @@
 - ARROW-12504: Buffer::from\_slice\_ref set correct capacity 
[\#18](https://github.com/apache/arrow-rs/pull/18) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([tustvold](https://github.com/tustvold))
 - Add GitHub templates [\#17](https://github.com/apache/arrow-rs/pull/17) 
([andygrove](https://github.com/andygrove))
 - ARROW-12493: Add support for writing dictionary arrays to CSV and JSON 
[\#16](https://github.com/apache/arrow-rs/pull/16) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([tustvold](https://github.com/tustvold))
-- ARROW-12426: \[Rust\] Fix concatentation of arrow dictionaries 
[\#15](https://github.com/apache/arrow-rs/pull/15) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([tustvold](https://github.com/tustvold))
+- ARROW-12426: \[Rust\] Fix concatenation of arrow dictionaries 
[\#15](https://github.com/apache/arrow-rs/pull/15) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
([tustvold](https://github.com/tustvold))
 - Update repository and homepage urls 
[\#14](https://github.com/apache/arrow-rs/pull/14) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)] 
[[arrow-flight](https://github.com/apache/arrow-rs/labels/arrow-flight)] 
[[parquet](https://github.com/apache/arrow-rs/labels/parquet)] 
([Dandandan](https://github.com/Dandandan))
 - Added rebase-needed bot [\#13](https://github.com/apache/arrow-rs/pull/13) 
([jorgecarleitao](https://github.com/jorgecarleitao))
 - Added Integration tests against arrow 
[\#10](https://github.com/apache/arrow-rs/pull/10) 
([jorgecarleitao](https://github.com/jorgecarleitao))
@@ -3108,7 +3108,7 @@
 - Support sort [\#215](https://github.com/apache/arrow-rs/issues/215) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Support stable Rust [\#214](https://github.com/apache/arrow-rs/issues/214) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
 - Remove Rust and point integration tests to arrow-rs repo 
[\#211](https://github.com/apache/arrow-rs/issues/211) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
-- ArrayData buffers are inconsistent accross implementations 
[\#207](https://github.com/apache/arrow-rs/issues/207)
+- ArrayData buffers are inconsistent across implementations 
[\#207](https://github.com/apache/arrow-rs/issues/207)
 - 3.0.1 patch release [\#204](https://github.com/apache/arrow-rs/issues/204)
 - Document patch release process 
[\#202](https://github.com/apache/arrow-rs/issues/202)
 - Simplify Offset [\#186](https://github.com/apache/arrow-rs/issues/186) 
[[arrow](https://github.com/apache/arrow-rs/labels/arrow)]
diff --git a/arrow-array/src/array/list_array.rs 
b/arrow-array/src/array/list_array.rs
index 8961d606e..8b314596d 100644
--- a/arrow-array/src/array/list_array.rs
+++ b/arrow-array/src/array/list_array.rs
@@ -182,7 +182,7 @@ impl<OffsetSize: OffsetSizeTrait> 
GenericListArray<OffsetSize> {
 impl<OffsetSize: OffsetSizeTrait> From<ArrayData> for 
GenericListArray<OffsetSize> {
     fn from(data: ArrayData) -> Self {
         Self::try_new_from_array_data(data).expect(
-            "Expected infallable creation of GenericListArray from 
ArrayDataRef failed",
+            "Expected infallible creation of GenericListArray from 
ArrayDataRef failed",
         )
     }
 }
diff --git a/arrow-array/src/array/map_array.rs 
b/arrow-array/src/array/map_array.rs
index fd4e2bd59..3d78387cd 100644
--- a/arrow-array/src/array/map_array.rs
+++ b/arrow-array/src/array/map_array.rs
@@ -106,7 +106,7 @@ impl MapArray {
 impl From<ArrayData> for MapArray {
     fn from(data: ArrayData) -> Self {
         Self::try_new_from_array_data(data)
-            .expect("Expected infallable creation of MapArray from ArrayData 
failed")
+            .expect("Expected infallible creation of MapArray from ArrayData 
failed")
     }
 }
 
diff --git a/arrow-array/src/array/mod.rs b/arrow-array/src/array/mod.rs
index ead8b3b99..589cf1eaf 100644
--- a/arrow-array/src/array/mod.rs
+++ b/arrow-array/src/array/mod.rs
@@ -266,7 +266,7 @@ pub trait Array: std::fmt::Debug + Send + Sync {
     #[allow(deprecated)] // (#3880)
     fn get_array_memory_size(&self) -> usize {
         // both data.get_array_memory_size and size_of_val(self) include 
ArrayData fields,
-        // to only count additional fields of this array substract 
size_of(ArrayData)
+        // to only count additional fields of this array subtract 
size_of(ArrayData)
         self.data_ref().get_array_memory_size() + std::mem::size_of_val(self)
             - std::mem::size_of::<ArrayData>()
     }
@@ -964,7 +964,7 @@ mod tests {
         let empty =
             
PrimitiveArray::<Int64Type>::from(ArrayData::new_empty(arr.data_type()));
 
-        // substract empty array to avoid magic numbers for the size of 
additional fields
+        // subtract empty array to avoid magic numbers for the size of 
additional fields
         assert_eq!(
             arr.get_array_memory_size() - empty.get_array_memory_size(),
             128 * std::mem::size_of::<i64>()
@@ -993,7 +993,7 @@ mod tests {
             empty_with_bitmap.get_array_memory_size()
         );
 
-        // substract empty array to avoid magic numbers for the size of 
additional fields
+        // subtract empty array to avoid magic numbers for the size of 
additional fields
         // the size of the validity bitmap is rounded up to 64 bytes
         assert_eq!(
             arr.get_array_memory_size() - 
empty_with_bitmap.get_array_memory_size(),
diff --git a/arrow-array/src/array/run_array.rs 
b/arrow-array/src/array/run_array.rs
index c3c526937..ada34b47f 100644
--- a/arrow-array/src/array/run_array.rs
+++ b/arrow-array/src/array/run_array.rs
@@ -202,7 +202,7 @@ impl<R: RunEndIndexType> RunArray<R> {
         // to iterate `logical_indices` in sorted order.
         let mut ordered_indices: Vec<usize> = (0..indices_len).collect();
 
-        // Instead of sorting `logical_idices` directly, sort the 
`ordered_indices`
+        // Instead of sorting `logical_indices` directly, sort the 
`ordered_indices`
         // whose values are index of `logical_indices`
         ordered_indices.sort_unstable_by(|lhs, rhs| {
             logical_indices[*lhs]
diff --git a/arrow-array/src/array/string_array.rs 
b/arrow-array/src/array/string_array.rs
index f339a616f..304f0ab3e 100644
--- a/arrow-array/src/array/string_array.rs
+++ b/arrow-array/src/array/string_array.rs
@@ -614,7 +614,7 @@ mod tests {
 
     #[test]
     #[should_panic(expected = "The child array cannot contain null values.")]
-    fn test_stirng_array_from_list_array_with_child_nulls_failed() {
+    fn test_string_array_from_list_array_with_child_nulls_failed() {
         
_test_generic_string_array_from_list_array_with_child_nulls_failed::<i32>();
     }
 
diff --git a/arrow-array/src/array/union_array.rs 
b/arrow-array/src/array/union_array.rs
index 335b6b14f..67848b4a8 100644
--- a/arrow-array/src/array/union_array.rs
+++ b/arrow-array/src/array/union_array.rs
@@ -957,7 +957,7 @@ mod tests {
     }
 
     #[test]
-    fn test_union_array_validaty() {
+    fn test_union_array_validity() {
         let mut builder = UnionBuilder::new_sparse();
         builder.append::<Int32Type>("a", 1).unwrap();
         builder.append_null::<Int32Type>("a").unwrap();
diff --git a/arrow-array/src/cast.rs b/arrow-array/src/cast.rs
index feb9167b2..21993114e 100644
--- a/arrow-array/src/cast.rs
+++ b/arrow-array/src/cast.rs
@@ -396,7 +396,7 @@ macro_rules! downcast_primitive_array {
 ///
 /// let arr: ArrayRef = Arc::new(Int32Array::from(vec![Some(1)]));
 ///
-/// // Downcast an `ArrayRef` to Int32Array / PrimiveArray<Int32>:
+/// // Downcast an `ArrayRef` to Int32Array / PrimitiveArray<Int32>:
 /// let primitive_array: &Int32Array = as_primitive_array(&arr);
 ///
 /// // Equivalently:
diff --git a/arrow-array/src/types.rs b/arrow-array/src/types.rs
index 60a632a06..827729ca6 100644
--- a/arrow-array/src/types.rs
+++ b/arrow-array/src/types.rs
@@ -517,7 +517,7 @@ impl Date32Type {
     /// # Arguments
     ///
     /// * `date` - The date on which to perform the operation
-    /// * `delta` - The interval to substract
+    /// * `delta` - The interval to subtract
     pub fn subtract_year_months(
         date: <Date32Type as ArrowPrimitiveType>::Native,
         delta: <IntervalYearMonthType as ArrowPrimitiveType>::Native,
@@ -641,7 +641,7 @@ impl Date64Type {
     /// # Arguments
     ///
     /// * `date` - The date on which to perform the operation
-    /// * `delta` - The interval to substract
+    /// * `delta` - The interval to subtract
     pub fn subtract_year_months(
         date: <Date64Type as ArrowPrimitiveType>::Native,
         delta: <IntervalYearMonthType as ArrowPrimitiveType>::Native,
diff --git a/arrow-csv/src/reader/mod.rs b/arrow-csv/src/reader/mod.rs
index 894c113ae..7fecc1ad9 100644
--- a/arrow-csv/src/reader/mod.rs
+++ b/arrow-csv/src/reader/mod.rs
@@ -183,7 +183,7 @@ fn infer_file_schema_with_csv_options<R: Read + Seek>(
 /// `max_read_records` controlling the maximum number of records to read. If 
`max_read_records` is
 /// not set, all records are read to infer the schema.
 ///
-/// Return infered schema and number of records used for inference.
+/// Return inferred schema and number of records used for inference.
 pub fn infer_reader_schema<R: Read>(
     reader: R,
     delimiter: u8,
@@ -287,7 +287,7 @@ fn infer_reader_schema_with_csv_options<R: Read>(
 /// Infer schema from a list of CSV files by reading through first n records
 /// with `max_read_records` controlling the maximum number of records to read.
 ///
-/// Files will be read in the given order untill n records have been reached.
+/// Files will be read in the given order until n records have been reached.
 ///
 /// If `max_read_records` is not set, all files will be read fully to infer 
the schema.
 pub fn infer_schema_from_files(
@@ -1048,14 +1048,14 @@ impl ReaderBuilder {
     }
 
     /// Set the datetime regex used to parse the string to Date64Type
-    /// this regex is used while infering schema
+    /// this regex is used while inferring schema
     pub fn with_datetime_re(mut self, datetime_re: Regex) -> Self {
         self.datetime_re = Some(datetime_re);
         self
     }
 
-    /// Set the datetime fromat used to parse the string to Date64Type
-    /// this fromat is used while when the schema wants to parse Date64Type.
+    /// Set the datetime format used to parse the string to Date64Type
+    /// this format is used while when the schema wants to parse Date64Type.
     ///
     /// For format refer to [chrono 
docs](https://docs.rs/chrono/0.4.19/chrono/format/strftime/index.html)
     ///
diff --git a/arrow-data/src/data/mod.rs b/arrow-data/src/data/mod.rs
index 581d4a10c..10bf97306 100644
--- a/arrow-data/src/data/mod.rs
+++ b/arrow-data/src/data/mod.rs
@@ -180,7 +180,7 @@ pub(crate) fn into_buffers(
 /// # Memory Layout
 ///
 /// `ArrayData` has references to one or more underlying data buffers
-/// and optional child ArrayDatas, depending on type as illustrated
+/// and optional child ArrayData, depending on type as illustrated
 /// below. Bitmaps are not shown for simplicity but they are stored
 /// similarly to the buffers.
 ///
diff --git a/arrow-data/src/transform/mod.rs b/arrow-data/src/transform/mod.rs
index 52ce5ead7..c74875072 100644
--- a/arrow-data/src/transform/mod.rs
+++ b/arrow-data/src/transform/mod.rs
@@ -418,7 +418,7 @@ impl<'a> MutableArrayData<'a> {
             | DataType::Interval(_)
             | DataType::FixedSizeBinary(_) => vec![],
             DataType::Map(_, _) | DataType::List(_) | DataType::LargeList(_) 
=> {
-                let childs = arrays
+                let children = arrays
                     .iter()
                     .map(|array| &array.child_data()[0])
                     .collect::<Vec<_>>();
@@ -435,7 +435,7 @@ impl<'a> MutableArrayData<'a> {
                 };
 
                 vec![MutableArrayData::with_capacities(
-                    childs, use_nulls, capacities,
+                    children, use_nulls, capacities,
                 )]
             }
             // the dictionary type just appends keys and clones the values.
@@ -495,11 +495,11 @@ impl<'a> MutableArrayData<'a> {
                 ]
             }
             DataType::FixedSizeList(_, _) => {
-                let childs = arrays
+                let children = arrays
                     .iter()
                     .map(|array| &array.child_data()[0])
                     .collect::<Vec<_>>();
-                vec![MutableArrayData::new(childs, use_nulls, array_capacity)]
+                vec![MutableArrayData::new(children, use_nulls, 
array_capacity)]
             }
             DataType::Union(fields, _) => (0..fields.len())
                 .map(|i| {
diff --git a/arrow-flight/src/client.rs b/arrow-flight/src/client.rs
index fe1292fcf..f843bbf7c 100644
--- a/arrow-flight/src/client.rs
+++ b/arrow-flight/src/client.rs
@@ -391,7 +391,7 @@ impl FlightClient {
     }
 
     /// Make a `ListFlights` call to the server with the provided
-    /// critera and returning a [`Stream`](futures::Stream) of [`FlightInfo`].
+    /// criteria and returning a [`Stream`](futures::Stream) of [`FlightInfo`].
     ///
     /// # Example:
     /// ```no_run
diff --git a/arrow-flight/src/error.rs b/arrow-flight/src/error.rs
index 5524dd1a4..e054883e9 100644
--- a/arrow-flight/src/error.rs
+++ b/arrow-flight/src/error.rs
@@ -30,7 +30,7 @@ pub enum FlightError {
     Tonic(tonic::Status),
     /// Some unexpected message was received
     ProtocolError(String),
-    /// An error occured during decoding
+    /// An error occurred during decoding
     DecodeError(String),
     /// External error that can provide source of error by calling 
`Error::source`.
     ExternalError(Box<dyn Error + Send + Sync>),
diff --git a/arrow-integration-testing/tests/ipc_reader.rs 
b/arrow-integration-testing/tests/ipc_reader.rs
index d6e81cd98..9205f4318 100644
--- a/arrow-integration-testing/tests/ipc_reader.rs
+++ b/arrow-integration-testing/tests/ipc_reader.rs
@@ -96,7 +96,7 @@ fn read_1_0_0_bigendian() {
         FileReader::try_new(file, None).unwrap();
 
         // While the the reader doesn't error but the values are not
-        // read correctly on little endian platforms so verifing the
+        // read correctly on little endian platforms so verifying the
         // contents fails
         //
         // https://github.com/apache/arrow-rs/issues/3459
diff --git a/arrow-ipc/src/compression.rs b/arrow-ipc/src/compression.rs
index e6e203bc0..dd60bfdee 100644
--- a/arrow-ipc/src/compression.rs
+++ b/arrow-ipc/src/compression.rs
@@ -98,7 +98,7 @@ impl CompressionCodec {
         // compressed
         let decompressed_length = read_uncompressed_size(input);
         let buffer = if decompressed_length == 0 {
-            // emtpy
+            // empty
             Buffer::from([])
         } else if decompressed_length == LENGTH_NO_COMPRESSED_DATA {
             // no compression
diff --git a/arrow-ipc/src/convert.rs b/arrow-ipc/src/convert.rs
index 334b9f656..cc2a7786c 100644
--- a/arrow-ipc/src/convert.rs
+++ b/arrow-ipc/src/convert.rs
@@ -161,7 +161,7 @@ pub fn try_schema_from_flatbuffer_bytes(bytes: &[u8]) -> 
Result<Schema, ArrowErr
 /// Try deserialize the IPC format bytes into a schema
 pub fn try_schema_from_ipc_buffer(buffer: &[u8]) -> Result<Schema, ArrowError> 
{
     // There are two protocol types: 
https://issues.apache.org/jira/browse/ARROW-6313
-    // The original protocal is:
+    // The original protocol is:
     //   4 bytes - the byte length of the payload
     //   a flatbuffer Message whose header is the Schema
     // The latest version of protocol is:
diff --git a/arrow-json/src/reader.rs b/arrow-json/src/reader.rs
index df6b998be..f5bf884fb 100644
--- a/arrow-json/src/reader.rs
+++ b/arrow-json/src/reader.rs
@@ -672,7 +672,7 @@ impl Decoder {
     }
 
     /// Read the next batch of [`serde_json::Value`] records from the
-    /// interator into a [`RecordBatch`].
+    /// iterator into a [`RecordBatch`].
     ///
     /// Returns `None` if the input iterator is exhausted.
     pub fn next_batch<I>(
@@ -2172,7 +2172,7 @@ mod tests {
     }
 
     #[test]
-    fn test_coersion_scalar_and_list() {
+    fn test_coercion_scalar_and_list() {
         use arrow_schema::DataType::*;
 
         assert_eq!(
diff --git a/arrow-json/src/writer.rs b/arrow-json/src/writer.rs
index 5d8abfafc..1b950f794 100644
--- a/arrow-json/src/writer.rs
+++ b/arrow-json/src/writer.rs
@@ -1233,7 +1233,7 @@ mod tests {
         let expected = read_to_string(test_file).unwrap();
         for (r, e) in result.lines().zip(expected.lines()) {
             let mut expected_json = serde_json::from_str::<Value>(e).unwrap();
-            // remove null value from object to make comparision consistent:
+            // remove null value from object to make comparison consistent:
             if let Value::Object(obj) = expected_json {
                 expected_json = Value::Object(
                     obj.into_iter().filter(|(_, v)| *v != 
Value::Null).collect(),
@@ -1424,7 +1424,7 @@ mod tests {
         let expected = read_to_string(test_file).unwrap();
         for (r, e) in result.lines().zip(expected.lines()) {
             let mut expected_json = serde_json::from_str::<Value>(e).unwrap();
-            // remove null value from object to make comparision consistent:
+            // remove null value from object to make comparison consistent:
             if let Value::Object(obj) = expected_json {
                 expected_json = Value::Object(
                     obj.into_iter().filter(|(_, v)| *v != 
Value::Null).collect(),
@@ -1468,7 +1468,7 @@ mod tests {
         let expected = format!("{expected}\n{expected}");
         for (r, e) in result.lines().zip(expected.lines()) {
             let mut expected_json = serde_json::from_str::<Value>(e).unwrap();
-            // remove null value from object to make comparision consistent:
+            // remove null value from object to make comparison consistent:
             if let Value::Object(obj) = expected_json {
                 expected_json = Value::Object(
                     obj.into_iter().filter(|(_, v)| *v != 
Value::Null).collect(),
diff --git a/arrow-ord/src/sort.rs b/arrow-ord/src/sort.rs
index 6e0becc36..b4f498813 100644
--- a/arrow-ord/src/sort.rs
+++ b/arrow-ord/src/sort.rs
@@ -383,7 +383,7 @@ pub fn sort_to_indices(
             DataType::Int64 => sort_run_to_indices::<Int64Type>(values, 
&options, limit),
             dt => {
                 return Err(ArrowError::ComputeError(format!(
-                    "Inavlid run end data type: {dt}"
+                    "Invalid run end data type: {dt}"
                 )))
             }
         },
@@ -771,7 +771,7 @@ where
     // Call the consumer using the run length and starting logical index.
     for physical_index in values_indices.values() {
         // As the values were sliced with offset = start_physical_index, it 
has to be added back
-        // before accesing `RunArray::run_ends`
+        // before accessing `RunArray::run_ends`
         let physical_index = *physical_index as usize + start_physical_index;
 
         // calculate the run length and logical index of sorted values
diff --git a/arrow-select/src/take.rs b/arrow-select/src/take.rs
index 83fe1bb56..2befcd054 100644
--- a/arrow-select/src/take.rs
+++ b/arrow-select/src/take.rs
@@ -36,7 +36,7 @@ use num::{ToPrimitive, Zero};
 /// │        A        │      │    0    │                              │        
A        │
 /// ├─────────────────┤      ├─────────┤                              
├─────────────────┤
 /// │        D        │      │    2    │                              │        
B        │
-/// ├─────────────────┤      ├─────────┤   take(values, indicies)     
├─────────────────┤
+/// ├─────────────────┤      ├─────────┤   take(values, indices)     
├─────────────────┤
 /// │        B        │      │    3    │ ─────────────────────────▶   │        
C        │
 /// ├─────────────────┤      ├─────────┤                              
├─────────────────┤
 /// │        C        │      │    1    │                              │        
D        │
diff --git a/arrow/examples/README.md b/arrow/examples/README.md
index 314ce9c62..7ec3b008b 100644
--- a/arrow/examples/README.md
+++ b/arrow/examples/README.md
@@ -22,6 +22,6 @@
 - [`builders.rs`](builders.rs): Using the Builder API
 - [`collect.rs`](collect.rs): Using the `FromIter` API
 - [`dynamic_types.rs`](dynamic_types.rs):
-- [`read_csv.rs`](read_csv.rs): Reading CSV files with explict schema, pretty 
printing Arrays
+- [`read_csv.rs`](read_csv.rs): Reading CSV files with explicit schema, pretty 
printing Arrays
 - [`read_csv_infer_schema.rs`](read_csv_infer_schema.rs): Reading CSV files, 
pretty printing Arrays
 - [`tensor_builder.rs`](tensor_builder.rs): Using tensor builder
diff --git a/arrow/src/util/bench_util.rs b/arrow/src/util/bench_util.rs
index b81990317..9bdc24783 100644
--- a/arrow/src/util/bench_util.rs
+++ b/arrow/src/util/bench_util.rs
@@ -179,7 +179,7 @@ pub fn create_primitive_run_array<R: RunEndIndexType, V: 
ArrowPrimitiveType>(
 }
 
 /// Create string array to be used by run array builder. The string array
-/// will result in run array with physial length of `physical_array_len`
+/// will result in run array with physical length of `physical_array_len`
 /// and logical length of `logical_array_len`
 pub fn create_string_array_for_runs(
     physical_array_len: usize,
diff --git a/arrow/src/util/data_gen.rs b/arrow/src/util/data_gen.rs
index 29e7420f1..0b0a06875 100644
--- a/arrow/src/util/data_gen.rs
+++ b/arrow/src/util/data_gen.rs
@@ -78,7 +78,7 @@ pub fn create_random_array(
         UInt64 => Arc::new(create_primitive_array::<UInt64Type>(size, 
null_density)),
         Float16 => {
             return Err(ArrowError::NotYetImplemented(
-                "Float16 is not implememted".to_string(),
+                "Float16 is not implemented".to_string(),
             ))
         }
         Float32 => Arc::new(create_primitive_array::<Float32Type>(size, 
null_density)),
diff --git a/dev/release/README.md b/dev/release/README.md
index 11bcbe866..c74d7d865 100644
--- a/dev/release/README.md
+++ b/dev/release/README.md
@@ -79,7 +79,7 @@ git commit -a -m 'Update version'
 export ARROW_GITHUB_API_TOKEN=<TOKEN>
 
 
-# manully edit ./dev/release/update_change_log.sh to reflect the release 
version
+# manually edit ./dev/release/update_change_log.sh to reflect the release 
version
 # create the changelog
 ./dev/release/update_change_log.sh
 
@@ -94,7 +94,7 @@ python dev/release/label_issues.py
 git commit -a -m 'Create changelog'
 
 
-# Manully edit ./dev/release/update_change_log.sh to reflect the release 
version
+# Manually edit ./dev/release/update_change_log.sh to reflect the release 
version
 # Create the changelog
 CHANGELOG_GITHUB_TOKEN=<TOKEN> ./dev/release/update_change_log.sh
 # Review change log / edit issues and labels if needed, rerun
@@ -227,7 +227,7 @@ Rust Arrow Crates:
 ./object_store/dev/release/release-tarball.sh 4.1.0 2
 ```
 
-Congratulations! The release is now offical!
+Congratulations! The release is now official!
 
 ### Publish on Crates.io
 
diff --git a/object_store/CHANGELOG-old.md b/object_store/CHANGELOG-old.md
index 58fb8a3b9..19a2766d2 100644
--- a/object_store/CHANGELOG-old.md
+++ b/object_store/CHANGELOG-old.md
@@ -217,6 +217,6 @@
 - Do not pretend to cache rust build artifacts, speed up CI by ~20% 
[\#2150](https://github.com/apache/arrow-rs/pull/2150) 
([alamb](https://github.com/alamb))
 - Port `object_store` integration tests, use github actions 
[\#2148](https://github.com/apache/arrow-rs/pull/2148) 
[[object-store](https://github.com/apache/arrow-rs/labels/object-store)] 
([alamb](https://github.com/alamb))
 - Port Add stream upload \(multi-part upload\)  
[\#2147](https://github.com/apache/arrow-rs/pull/2147) 
[[object-store](https://github.com/apache/arrow-rs/labels/object-store)] 
([alamb](https://github.com/alamb))
-- Increase upper wait time to reduce flakyness of object store test 
[\#2142](https://github.com/apache/arrow-rs/pull/2142) 
[[object-store](https://github.com/apache/arrow-rs/labels/object-store)] 
([viirya](https://github.com/viirya))
+- Increase upper wait time to reduce flakiness of object store test 
[\#2142](https://github.com/apache/arrow-rs/pull/2142) 
[[object-store](https://github.com/apache/arrow-rs/labels/object-store)] 
([viirya](https://github.com/viirya))
 
 \* *This Changelog was automatically generated by 
[github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
diff --git a/object_store/src/azure/client.rs b/object_store/src/azure/client.rs
index c5a5652ab..494303dff 100644
--- a/object_store/src/azure/client.rs
+++ b/object_store/src/azure/client.rs
@@ -436,7 +436,7 @@ fn to_list_result(value: ListResultInternal, prefix: 
Option<&str>) -> Result<Lis
         // Note: workaround for gen2 accounts with hierarchical namespaces. 
These accounts also
         // return path segments as "directories" and include blobs in list 
requests with prefix,
         // if the prefix mateches the blob. When we want directories, its 
always via
-        // the BlobPrefix mechanics, and during lists we state that prefixes 
are evaluated on path segement basis.
+        // the BlobPrefix mechanics, and during lists we state that prefixes 
are evaluated on path segment basis.
         .filter_map_ok(|obj| {
             if obj.size > 0 && obj.location.as_ref().len() > 
prefix.as_ref().len() {
                 Some(obj)
diff --git a/parquet/src/arrow/arrow_reader/mod.rs 
b/parquet/src/arrow/arrow_reader/mod.rs
index 950796783..ba322e29d 100644
--- a/parquet/src/arrow/arrow_reader/mod.rs
+++ b/parquet/src/arrow/arrow_reader/mod.rs
@@ -2642,7 +2642,7 @@ mod tests {
     }
 
     #[test]
-    fn test_arbitary_decimal() {
+    fn test_arbitrary_decimal() {
         let values = [1, 2, 3, 4, 5, 6, 7, 8];
         let decimals_19_0 = Decimal128Array::from_iter_values(values)
             .with_precision_and_scale(19, 0)
diff --git a/parquet/src/arrow/arrow_reader/selection.rs 
b/parquet/src/arrow/arrow_reader/selection.rs
index d3abf968b..76f950620 100644
--- a/parquet/src/arrow/arrow_reader/selection.rs
+++ b/parquet/src/arrow/arrow_reader/selection.rs
@@ -1116,7 +1116,7 @@ mod tests {
             RowSelector::select(5),
             // Skip full page past page boundary
             RowSelector::skip(12),
-            // Select to final page bounday
+            // Select to final page boundary
             RowSelector::select(12),
             RowSelector::skip(1),
             // Skip across final page boundary
diff --git a/parquet/src/basic.rs b/parquet/src/basic.rs
index 266c0436b..ec1d4a07a 100644
--- a/parquet/src/basic.rs
+++ b/parquet/src/basic.rs
@@ -2023,7 +2023,7 @@ mod tests {
     }
 
     #[test]
-    fn test_column_order_get_coverted_type_sort_order() {
+    fn test_column_order_get_converted_type_sort_order() {
         // Helper to check the order in a list of values.
         // Only converted type is checked.
         fn check_sort_order(types: Vec<ConvertedType>, expected_order: 
SortOrder) {
diff --git a/parquet/src/compression.rs b/parquet/src/compression.rs
index 4c4057e7a..f1831ed48 100644
--- a/parquet/src/compression.rs
+++ b/parquet/src/compression.rs
@@ -726,7 +726,7 @@ mod lz4_hadoop_codec {
                 }
                 Err(e) if !self.backward_compatible_lz4 => Err(e.into()),
                 // Fallback done to be backward compatible with older versions 
of this
-                // libray and older versions of parquet-cpp.
+                // library and older versions of parquet-cpp.
                 Err(_) => {
                     // Truncate any inserted element before tryingg next 
algorithm.
                     output_buf.truncate(output_len);
diff --git a/parquet/src/data_type.rs b/parquet/src/data_type.rs
index 48ee7f89f..2e7f73bf0 100644
--- a/parquet/src/data_type.rs
+++ b/parquet/src/data_type.rs
@@ -106,7 +106,7 @@ pub struct ByteArray {
     data: Option<ByteBufferPtr>,
 }
 
-// Special case Debug that prints out byte arrays that are vaid utf8 as &str's
+// Special case Debug that prints out byte arrays that are valid utf8 as &str's
 impl std::fmt::Debug for ByteArray {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         let mut debug_struct = f.debug_struct("ByteArray");
@@ -259,7 +259,7 @@ impl fmt::Display for ByteArray {
 /// types, although there are code paths in the Rust (and potentially the C++) 
versions that
 /// warrant this.
 ///
-/// With this wrapper type the compiler generates more targetted code paths 
matching the higher
+/// With this wrapper type the compiler generates more targeted code paths 
matching the higher
 /// level logical types, removing the data-hazard from all decoding and 
encoding paths.
 #[repr(transparent)]
 #[derive(Clone, Debug, Default)]
diff --git a/parquet/src/file/serialized_reader.rs 
b/parquet/src/file/serialized_reader.rs
index e5ed26e9e..2ddbf0f7c 100644
--- a/parquet/src/file/serialized_reader.rs
+++ b/parquet/src/file/serialized_reader.rs
@@ -1327,7 +1327,7 @@ mod tests {
     // parquet-tools column-index ./data_index_bloom_encoding_stats.parquet
     // row group 0:
     // column index for column String:
-    // Boudary order: ASCENDING
+    // Boundary order: ASCENDING
     // page-0  :
     // null count                 min                                  max
     // 0                          Hello                                today
diff --git a/parquet/src/record/api.rs b/parquet/src/record/api.rs
index 49fdc3fc7..1809e3ace 100644
--- a/parquet/src/record/api.rs
+++ b/parquet/src/record/api.rs
@@ -133,7 +133,7 @@ pub trait RowAccessor {
     fn get_map(&self, i: usize) -> Result<&Map>;
 }
 
-/// Trait for formating fields within a Row.
+/// Trait for formatting fields within a Row.
 ///
 /// # Examples
 ///
diff --git a/parquet/src/record/reader.rs b/parquet/src/record/reader.rs
index eb16c13f6..b7298a45b 100644
--- a/parquet/src/record/reader.rs
+++ b/parquet/src/record/reader.rs
@@ -611,7 +611,7 @@ impl fmt::Display for Reader {
 // ----------------------------------------------------------------------
 // Row iterators
 
-/// The enum Either with variants That represet a reference and a box of
+/// The enum Either with variants That represents a reference and a box of
 /// [`FileReader`](crate::file::reader::FileReader).
 enum Either<'a> {
     Left(&'a dyn FileReader),
diff --git a/parquet/src/record/triplet.rs b/parquet/src/record/triplet.rs
index b7318b3d3..14a4a3945 100644
--- a/parquet/src/record/triplet.rs
+++ b/parquet/src/record/triplet.rs
@@ -496,7 +496,7 @@ mod tests {
         }
     }
 
-    // Check values of a selectd column in a file
+    // Check values of a selected column in a file
     fn test_column_in_file(
         file_name: &str,
         batch_size: usize,

Reply via email to
diff --git a/arrow-flight/tests/encode_decode.rs 
b/arrow-flight/tests/encode_decode.rs
index 2841d4bf5..ec86fbcc0 100644
--- a/arrow-flight/tests/encode_decode.rs
+++ b/arrow-flight/tests/encode_decode.rs
@@ -38,7 +38,7 @@ async fn test_empty() {
 
 #[tokio::test]
 async fn test_empty_batch() {
-    let batch = make_primative_batch(5);
+    let batch = make_primitive_batch(5);
     let empty = RecordBatch::new_empty(batch.schema());
     roundtrip(vec![empty]).await;
 }
@@ -59,13 +59,13 @@ async fn test_error() {
 }
 
 #[tokio::test]
-async fn test_primative_one() {
-    roundtrip(vec![make_primative_batch(5)]).await;
+async fn test_primitive_one() {
+    roundtrip(vec![make_primitive_batch(5)]).await;
 }
 
 #[tokio::test]
 async fn test_schema_metadata() {
-    let batch = make_primative_batch(5);
+    let batch = make_primitive_batch(5);
     let metadata = HashMap::from([("some_key".to_owned(), 
"some_value".to_owned())]);
 
     // create a batch that has schema level metadata
@@ -76,18 +76,18 @@ async fn test_schema_metadata() {
 }
 
 #[tokio::test]
-async fn test_primative_many() {
+async fn test_primitive_many() {
     roundtrip(vec![
-        make_primative_batch(1),
-        make_primative_batch(7),
-        make_primative_batch(32),
+        make_primitive_batch(1),
+        make_primitive_batch(7),
+        make_primitive_batch(32),
     ])
     .await;
 }
 
 #[tokio::test]
-async fn test_primative_empty() {
-    let batch = make_primative_batch(5);
+async fn test_primitive_empty() {
+    let batch = make_primitive_batch(5);
     let empty = RecordBatch::new_empty(batch.schema());
 
     roundtrip(vec![batch, empty]).await;
@@ -137,7 +137,7 @@ async fn test_zero_batches_schema_specified() {
 }
 
 #[tokio::test]
-async fn test_zero_batches_dictonary_schema_specified() {
+async fn test_zero_batches_dictionary_schema_specified() {
     let schema = Arc::new(Schema::new(vec![
         Field::new("a", DataType::Int64, false),
         Field::new(
@@ -166,7 +166,7 @@ async fn test_zero_batches_dictonary_schema_specified() {
 
 #[tokio::test]
 async fn test_app_metadata() {
-    let input_batch_stream = 
futures::stream::iter(vec![Ok(make_primative_batch(78))]);
+    let input_batch_stream = 
futures::stream::iter(vec![Ok(make_primitive_batch(78))]);
 
     let app_metadata = Bytes::from("My Metadata");
     let encoder = 
FlightDataEncoderBuilder::default().with_metadata(app_metadata.clone());
@@ -196,7 +196,7 @@ async fn test_app_metadata() {
 
 #[tokio::test]
 async fn test_max_message_size() {
-    let input_batch_stream = 
futures::stream::iter(vec![Ok(make_primative_batch(5))]);
+    let input_batch_stream = 
futures::stream::iter(vec![Ok(make_primitive_batch(5))]);
 
     // 5 input rows, with a very small limit should result in 5 batch messages
     let encoder = 
FlightDataEncoderBuilder::default().with_max_flight_data_size(1);
@@ -223,13 +223,13 @@ async fn test_max_message_size_fuzz() {
     // send through batches of varying sizes with various max
     // batch sizes and ensure the data gets through ok
     let input = vec![
-        make_primative_batch(123),
-        make_primative_batch(17),
-        make_primative_batch(201),
-        make_primative_batch(2),
-        make_primative_batch(1),
-        make_primative_batch(11),
-        make_primative_batch(127),
+        make_primitive_batch(123),
+        make_primitive_batch(17),
+        make_primitive_batch(201),
+        make_primitive_batch(2),
+        make_primitive_batch(1),
+        make_primitive_batch(11),
+        make_primitive_batch(127),
     ];
 
     for max_message_size_bytes in [10, 1024, 2048, 6400, 3211212] {
@@ -257,7 +257,7 @@ async fn test_max_message_size_fuzz() {
 async fn test_mismatched_record_batch_schema() {
     // send 2 batches with different schemas
     let input_batch_stream = futures::stream::iter(vec![
-        Ok(make_primative_batch(5)),
+        Ok(make_primitive_batch(5)),
         Ok(make_dictionary_batch(3)),
     ]);
 
@@ -274,7 +274,7 @@ async fn test_mismatched_record_batch_schema() {
 
 #[tokio::test]
 async fn test_chained_streams_batch_decoder() {
-    let batch1 = make_primative_batch(5);
+    let batch1 = make_primitive_batch(5);
     let batch2 = make_dictionary_batch(3);
 
     // Model sending two flight streams back to back, with different schemas
@@ -299,7 +299,7 @@ async fn test_chained_streams_batch_decoder() {
 
 #[tokio::test]
 async fn test_chained_streams_data_decoder() {
-    let batch1 = make_primative_batch(5);
+    let batch1 = make_primitive_batch(5);
     let batch2 = make_dictionary_batch(3);
 
     // Model sending two flight streams back to back, with different schemas
@@ -363,27 +363,27 @@ async fn test_mismatched_schema_message() {
 
     // primitive batch first (has more columns)
     do_test(
-        make_primative_batch(5),
+        make_primitive_batch(5),
         make_dictionary_batch(3),
         "Error decoding ipc RecordBatch: Io error: Invalid data for schema",
     )
     .await;
 
     // dictioanry batch first
     do_test(
         make_dictionary_batch(3),
-        make_primative_batch(5),
+        make_primitive_batch(5),
         "Error decoding ipc RecordBatch: Invalid argument error",
     )
     .await;
 }
 
 /// Make a primtive batch for testing
 ///
 /// Example:
 /// i: 0, 1, None, 3, 4
 /// f: 5.0, 4.0, None, 2.0, 1.0
-fn make_primative_batch(num_rows: usize) -> RecordBatch {
+fn make_primitive_batch(num_rows: usize) -> RecordBatch {
     let i: UInt8Array = (0..num_rows)
         .map(|i| {
             if i == num_rows / 2 {
@@ -363,27 +363,27 @@ async fn test_mismatched_schema_message() {
     .await;
 
-    // dictioanry batch first
+    // dictionary batch first
     do_test(
         make_dictionary_batch(3),
@@ -363,27 +363,27 @@ async fn test_mismatched_schema_message() {
 }
 
-/// Make a primtive batch for testing
+/// Make a primitive batch for testing
 ///
 /// Example: